<?php

declare(strict_types=1);

namespace FiloBlu\Refilo\Model;

use Magento\Catalog\Api\Data\ProductInterface;
use Magento\Catalog\Api\ProductRepositoryInterface;

/**
 * Class Upsell
 * @package FiloBlu\Refilo\Model
 */
class Crosssell extends \Magento\TargetRule\Block\Checkout\Cart\Crosssell
{

    /**
     * @var ProductInterface|null
     */
    protected $currentProduct = null;


    /**
     * @return ProductInterface|null
     */
    public function getProduct()
    {
        return $this->currentProduct;
    }

    /**
     * @param ProductInterface $product
     * @return $this
     */
    public function setProduct(ProductInterface $product)
    {
        $id = $product->hasData('row_id') ? $product->getData('row_id') : $product->getId();
        $this->_products[$id] = $product;
        $this->currentProduct = $product;
        return $this;
    }

    /**
     * @return false
     */
    public function isShuffled()
    {
        return false;
    }

    /**
     * Retrieve just added to cart product id
     *
     * @return int
     */
    public function getLastAddedProductId()
    {
        return $this->currentProduct ? $this->currentProduct->getId() : 0;
    }

    /**
     * Retrieve array of cross-sell products
     *
     * @return array
     */
    public function getItemCollection()
    {
        $products = parent::getItemCollection();
        $ids = array_map(static function ($a) {
            return (int)$a->getId();
        }, $products);
        return $ids ? array_keys($ids) : [];
    }

    /**
     * @return int
     * @see \Magento\TargetRule\Helper\Data
     * Retrieve Maximum Number Of Product
     *
     */
    public function getPositionLimit()
    {
        return 1000;
    }
}
